==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/script/ScriptEvent.hpp <==
#ifndef _COM_SUN_STAR_SCRIPT_SCRIPTEVENT_HPP_
#define _COM_SUN_STAR_SCRIPT_SCRIPTEVENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_SCRIPTEVENT_HDL_
#include "com/sun/star/script/ScriptEvent.hdl"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_ALLEVENTOBJECT_HPP_
#include "com/sun/star/script/AllEventObject.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace script {

inline ScriptEvent::ScriptEvent() SAL_THROW( () )
    : ::com::sun::star::script::AllEventObject()
    , ScriptType()
    , ScriptCode()
{
}

inline ScriptEvent::ScriptEvent(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Source_, const ::com::sun::star::uno::Any& Helper_, const ::com::sun::star::uno::Type& ListenerType_, const ::rtl::OUString& MethodName_, const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >& Arguments_, const ::rtl::OUString& ScriptType_, const ::rtl::OUString& ScriptCode_) SAL_THROW( () )
    : ::com::sun::star::script::AllEventObject(Source_, Helper_, ListenerType_, MethodName_, Arguments_)
    , ScriptType(ScriptType_)
    , ScriptCode(ScriptCode_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::script::ScriptEvent const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.script.ScriptEvent");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_SCRIPT_SCRIPTEVENT_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/script/ScriptEvent.hpp <==
#ifndef _COM_SUN_STAR_SCRIPT_SCRIPTEVENT_HPP_
#define _COM_SUN_STAR_SCRIPT_SCRIPTEVENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_SCRIPTEVENT_HDL_
#include "com/sun/star/script/ScriptEvent.hdl"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_ALLEVENTOBJECT_HPP_
#include "com/sun/star/script/AllEventObject.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace script {

inline ScriptEvent::ScriptEvent() SAL_THROW( () )
    : ::com::sun::star::script::AllEventObject()
    , ScriptType()
    , ScriptCode()
{
}

inline ScriptEvent::ScriptEvent(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Source_, const ::com::sun::star::uno::Any& Helper_, const ::com::sun::star::uno::Type& ListenerType_, const ::rtl::OUString& MethodName_, const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >& Arguments_, const ::rtl::OUString& ScriptType_, const ::rtl::OUString& ScriptCode_) SAL_THROW( () )
    : ::com::sun::star::script::AllEventObject(Source_, Helper_, ListenerType_, MethodName_, Arguments_)
    , ScriptType(ScriptType_)
    , ScriptCode(ScriptCode_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace script {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::script::ScriptEvent const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.script.ScriptEvent");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::script::ScriptEvent const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::script::ScriptEvent >::get();
}

#endif // _COM_SUN_STAR_SCRIPT_SCRIPTEVENT_HPP_
